@@ -1,7 +1,7 @@
 /*
  *	The PCI Library -- ID to Name Translation
  *
- *	Copyright (c) 1997--2006 Martin Mares <mj@ucw.cz>
+ *	Copyright (c) 1997--2008 Martin Mares <mj@ucw.cz>
  *
  *	Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -26,7 +26,7 @@ static pci_file pci_open(struct pci_access *a)
   size_t len;
   char *new_name;
 
-  result = gzopen(a->id_file_name, "r");
+  result = gzopen(a->id_file_name, "rb");
   if (result)
     return result;
   len = strlen(a->id_file_name);
@@ -36,16 +36,17 @@ static pci_file pci_open(struct pci_access *a)
   memcpy(new_name, a->id_file_name, len - 3);
   new_name[len - 3] = 0;
   pci_set_name_list_path(a, new_name, 1);
-  return gzopen(a->id_file_name, "r");
+  return gzopen(a->id_file_name, "rb");
 }
 
 #define pci_close(f)		gzclose(f)
 #define PCI_ERROR(f, err)						\
 	if (!err) {							\
 		int errnum;						\
-		err = gzerror(f, &errnum);				\
-		if (errnum == Z_ERRNO)	err = "I/O error";		\
-		else if (errnum >= 0)	err = NULL;			\
+		gzerror(f, &errnum);					\
+		if (errnum >= 0) err = NULL;				\
+		else if (errnum == Z_ERRNO) err = "I/O error";		\
+		else err = zError(errnum);				\
 	}
 #else
 typedef FILE * pci_file;
@@ -326,7 +327,7 @@ pci_load_name_list(struct pci_access *a)
   if (!(f = pci_open(a)))
     return 0;
   a->id_hash = pci_malloc(a, sizeof(struct id_entry *) * HASH_SIZE);
-  bzero(a->id_hash, sizeof(struct id_entry *) * HASH_SIZE);
+  memset(a->id_hash, 0, sizeof(struct id_entry *) * HASH_SIZE);
   err = id_parse_list(a, f, &lino);
   PCI_ERROR(f, err);
   pci_close(f);
